@@ -54,6 +54,24 @@ class _NamedTemporaryFile(object):
         os.remove(self.name)
 
 
+def _tempdir_maker():
+    import contextlib
+    import shutil
+    import tempfile
+
+    @contextlib.contextmanager
+    def _tempdir_mgr():
+        temp_dir = tempfile.mkdtemp()
+        yield temp_dir
+        shutil.rmtree(temp_dir)
+
+    return _tempdir_mgr
+
+
+_tempdir = _tempdir_maker()
+del _tempdir_maker
+
+
 class _GAXBaseAPI(object):
 
     _random_gax_error = False
@@ -61,12 +79,12 @@ class _GAXBaseAPI(object):
     def __init__(self, **kw):
         self.__dict__.update(kw)
 
-    def _make_grpc_error(self, status_code):
+    def _make_grpc_error(self, status_code, trailing=None):
         from grpc._channel import _RPCState
         from google.cloud.exceptions import GrpcRendezvous
 
         details = 'Some error details.'
-        exc_state = _RPCState((), None, None, status_code, details)
+        exc_state = _RPCState((), None, trailing, status_code, details)
         return GrpcRendezvous(exc_state, None, None, None)
 
     def _make_grpc_not_found(self):
@@ -77,6 +95,10 @@ class _GAXBaseAPI(object):
         from grpc import StatusCode
         return self._make_grpc_error(StatusCode.FAILED_PRECONDITION)
 
+    def _make_grpc_deadline_exceeded(self):
+        from grpc import StatusCode
+        return self._make_grpc_error(StatusCode.DEADLINE_EXCEEDED)
+
 
 class _GAXPageIterator(object):
 
